/* eslint-disable @typescript-eslint/no-unused-vars */
import React from 'react';
import { Button, Layout, Menu, Spin, Empty, message } from 'antd'
import Chat from './Chat'
import 'antd/dist/antd.css'
import './App.css';
declare const AIM: any;
const {
    IMSDK, // 核心 SDK
    DataSDK, // 数据 SDK
    constants, // 常量定义
    convFeature, // 会话相关辅助函数
    msgFeature, // 消息相关辅助函数
    initStore, // 数据 SDK，初始化 Store
    getFileUrl,  // 获取文件访问地址
    mediaId, // 资源 ID 工具,
    ConnectionStatus,
    EventNameEnum,
} = AIM

const appName = 'aim_demo'
const appKey = '436687f56d19ee4250673f5a2df13ba7'

function App() {
    const [loginStatus, setLoginStatus] = React.useState(ConnectionStatus.CONN_UNCONNECTED);
    const isLoginSucc = React.useMemo(() => loginStatus === ConnectionStatus.CONN_AUTHED, [loginStatus])
    const isLoading = React.useMemo(() => !isLoginSucc && loginStatus !== ConnectionStatus.CONN_UNCONNECTED, [loginStatus])
    const login = React.useCallback(async (openId: string) => {
        const Setting = {
            appKey, // 应用key IM_PAAS分配给应用的key
            deviceId: await IMSDK.getAuthService().getDeviceId(), // 设备唯一id
            appName, // app_name 应用名称
            debug: true,
            log: {
                error(...args: any[]) {
                    console.error(...args);
                    // 这里应该上报 异常日志
                },
                info(...args: any[]) {
                    console.info(...args);
                },
            },
            async authTokenCallback() {
                return fetch(
                    `getLoginToken?domain=${Setting.appName}&appuid=${openId}&deviceId=${Setting.deviceId}&appkey=${Setting.appKey}&unit=nanTong`,
                )
                    .then((res) => res.json())
                    .then((res) => {
                        if (res) {
                            try {
                                const authToken = res;
                                return { ...authToken, uid: openId };
                            } catch (err) {
                                throw err;
                            }
                        }
                        throw new Error('token is null');
                    });
            }, // on_callback 获取登录token的回调函数（注意需要做成异步操作，不能有阻塞）
        };
        IMSDK.getSettingService().set(Setting);
        IMSDK.getAuthService().login();
    }, []);
    const logout = React.useCallback(() => {
        IMSDK.getAuthService().logout();
    }, []);

    React.useEffect(() => {
        IMSDK.getEventService().register((eventName: string, eventData: any) => {
            console.log('== event ==', { eventName, eventData });
            switch (eventName) {
                case EventNameEnum.PaaSConnectionChanged:
                    setLoginStatus(eventData);
                    if (eventData === ConnectionStatus.CONN_AUTHED) {
                        message.success('登录成功！')
                    }
                    break;
            }
        });
    }, []);
    return (
        <Layout className="layout">
            <Layout.Header className="layout-header">
                <div className="logo">AIM DEMO</div>
                {isLoginSucc && <Button type="default" onClick={logout} size="small">退出</Button>}
            </Layout.Header>
            <Layout>
                {isLoginSucc ? <Chat /> : (
                    <Empty description="" style={{ marginTop: 50 }}>
                        {isLoading ? <Spin>登录中...</Spin> : (
                        <Button type="primary" onClick={() => {
                            const uid = prompt('请输入测试UID，范围：test001-test999', 'test001')
                            if (uid) {
                                login(uid);
                            }
                        }} size="large">点击登录</Button>
                        )}
                    </Empty>
                )}
            </Layout>
        </Layout>
    );
}

export default App;
