import React, { FunctionComponent } from 'react';
import { Image } from 'antd';
import _get from 'lodash/get';
import './ImgMsg.css';
declare const AIM: any;
const {
    IMSDK,
    mediaId: {
        isMediaId,
        mid2Object,
        mid2Url,
    },
    getFileUrl,
} = AIM

export interface IProps {
    msg: any;
}

const MAX_SIZE = 360;

export const ImgMsg: FunctionComponent<IProps> = React.memo(({ msg }: IProps) => {

    let defaultMidObj = {
        width: parseInt(msg.message?.content?.photo?.extension?.width || '0', 10),
        height: parseInt(msg.message?.content?.photo?.extension?.height || '0', 10),
        url: '',
        type: [],
    };
    const [
        midObj,
        setMidObj,
    ] = React.useState<{ width: number; height: number; url: string; type: string[] }>(defaultMidObj)

    // 原始URL
    const [ previewSrc, setPreviewSrc ] = React.useState<string>('')
    React.useEffect(() => {
        const mediaId = msg?.message?.content?.photo?.mediaId || '';
        const fileType = `${msg.message?.content?.photo?.type || ''}`; // 可传空
        const cid = _get(msg, 'message.appCid') || '';
        const msgId = msg.message?.messageId || '';

        let originSize = mid2Object(mediaId, {
            imageSize: 'origin',
            queryParams: {
                auth_bizType: 'impaas',
                bizType: 'impaas',
                auth_bizEntity: JSON.stringify({ cid, msgId }),
                domain: IMSDK.getAuthService().getDomain() || '',
            },
        })
        let result = {
            width: parseInt(msg.message?.content?.photo?.extension?.width || '0', 10) || originSize.width,
            height: parseInt(msg.message?.content?.photo?.extension?.height || '0', 10) || originSize.height,
            url: '',
            type: [],
        };
        if (mediaId.indexOf('data:image') === 0 || mediaId.indexOf('http') === 0) {
            result.url = mediaId;
            setMidObj(result)
            setPreviewSrc(mediaId)
        } else if (mediaId && isMediaId(mediaId)) {
            // getFileUrl 参数：
            // mediaId: string, fileType: string, cid: string, msgId: string, type: 'normal' | 'origin' = 'origin'
            // origin 原图， normal 缩略图
            getFileUrl(mediaId, fileType, cid, msgId, 'normal').then((res: string) => {
                if (res) {
                    result.url = res;
                    setMidObj(result)
                }
            });
            getFileUrl(mediaId, fileType, cid, msgId, 'origin').then((res: string) => {
                if (res) {
                    setPreviewSrc(res)
                }
            });
        }
    }, [msg?.message?.content])

    const [width, height] = React.useMemo(() => {
        let width = parseInt(msg?.message?.content?.photo?.extension?.width || '0', 10) || midObj.width || 0;
        let height = parseInt(msg.message?.content?.photo?.extension?.height || '0', 10) || midObj.height || 0;
        if (midObj.width && midObj.height) {
            if (midObj.width > midObj.height && midObj.width > MAX_SIZE) {
                width = MAX_SIZE;
                height = midObj.height * (MAX_SIZE / midObj.width);
            } else if (midObj.width <= midObj.height && midObj.height > MAX_SIZE) {
                height = MAX_SIZE;
                width = midObj.width * (MAX_SIZE / midObj.height);
            }
        }
        return [width, height];
    }, [midObj]);

    return (
        <div className="img-msg">
            <Image src={midObj.url} width={width} height={height} preview={{
                src: previewSrc,
            }} />
        </div>
    );
});
